# typicle

A package solely for providing consistent data types across my other high
energy physics packages.

You're welcome to make use of this, although I don't foresee many features, or
any vigorous development.
